/*
 * Copyright © 2004-2021 L2J DataPack
 * 
 * This file is part of L2J DataPack.
 * 
 * L2J DataPack is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * L2J DataPack is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package com.l2jserver.datapack.handlers.targethandlers;

import java.util.ArrayList;
import java.util.List;

import com.l2jserver.gameserver.GeoData;
import com.l2jserver.gameserver.handler.ITargetTypeHandler;
import com.l2jserver.gameserver.model.L2Object;
import com.l2jserver.gameserver.model.actor.L2Character;
import com.l2jserver.gameserver.model.actor.instance.L2PcInstance;
import com.l2jserver.gameserver.model.actor.instance.L2SiegeFlagInstance;
import com.l2jserver.gameserver.model.skills.Skill;
import com.l2jserver.gameserver.model.skills.targets.TargetType;
import com.l2jserver.gameserver.model.zone.ZoneId;

/**
 * Aura Friendly target handler implementation.
 * @author Sahar
 */
public class AuraFriendly implements ITargetTypeHandler {
	@Override
	public L2Object[] getTargetList(Skill skill, L2Character activeChar, boolean onlyFirst, L2Character target) {
		List<L2Character> targetList = new ArrayList<>();
		L2PcInstance player = activeChar.getActingPlayer();
		int maxTargets = skill.getAffectLimit();
		for (L2Character obj : player.getKnownList().getKnownCharactersInRadius(skill.getAffectRange())) {
			if ((obj == activeChar) || !checkTarget(player, obj)) {
				continue;
			}
			
			if ((maxTargets > 0) && (targetList.size() >= maxTargets)) {
				break;
			}
			
			targetList.add(obj);
		}
		
		if (targetList.isEmpty()) {
			return EMPTY_TARGET_LIST;
		}
		
		return targetList.toArray(EMPTY_TARGET_LIST);
	}
	
	private boolean checkTarget(L2PcInstance activeChar, L2Character target) {
		if ((target == null) || !GeoData.getInstance().canSeeTarget(activeChar, target)) {
			return false;
		}
		
		if (target.isAlikeDead() || target.isDoor() || (target instanceof L2SiegeFlagInstance) || target.isMonster()) {
			return false;
		}
		
		if (target.isPlayable()) {
			L2PcInstance targetPlayer = target.getActingPlayer();
			
			if (activeChar.isInDuelWith(target)) {
				return false;
			}
			
			if (activeChar.isInPartyWith(target)) {
				return true;
			}
			
			if (target.isInsideZone(ZoneId.PVP)) {
				return false;
			}
			
			if (activeChar.isInClanWith(target) || activeChar.isInAllyWith(target) || activeChar.isInCommandChannelWith(target)) {
				return true;
			}
			
			if ((targetPlayer.getPvpFlag() > 0) || (targetPlayer.getKarma() > 0)) {
				return false;
			}
		}
		
		return true;
	}
	
	@Override
	public Enum<TargetType> getTargetType() {
		return TargetType.AURA_FRIENDLY;
	}
}